@@ -1,5 +1,5 @@
 # Copyright (c) 2012-2013 Erik Johansson <erik@ejohansson.se>
-# 
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
 # published by the Free Software Foundation; either version 3 of the
@@ -21,10 +21,10 @@ Contains all constants used in the API.
 All the TELLSTICK_* defines documented in the `Telldus Core documentation
 <http://developer.telldus.com/doxygen/group__core.html>`_ are available here.
 
-The recommended usage is to simply do::
-    from tellcore.constants import *
+The recommended usage is to do::
+    import tellcore.constants as const
 
-The constants will then be available as TELLSTICK_TURNON, etc.
+The constants will then be available as const.TELLSTICK_TURNON, etc.
 """
 
 # Device methods
@@ -42,6 +42,11 @@ TELLSTICK_STOP = 512
 # Sensor value types
 TELLSTICK_TEMPERATURE = 1
 TELLSTICK_HUMIDITY = 2
+TELLSTICK_RAINRATE = 4
+TELLSTICK_RAINTOTAL = 8
+TELLSTICK_WINDDIRECTION = 16
+TELLSTICK_WINDAVERAGE = 32
+TELLSTICK_WINDGUST = 64
 
 # Error codes
 TELLSTICK_SUCCESS = 0
