@@ -1,5 +1,5 @@
 # Copyright (c) 2012-2013 Erik Johansson <erik@ejohansson.se>
-# 
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
 # published by the Free Software Foundation; either version 3 of the
@@ -15,18 +15,23 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 # USA
 
-from ctypes import c_bool, c_char_p, c_int, c_ubyte, c_ulong, c_void_p
+from ctypes import c_bool, c_char_p, c_int, c_ubyte, c_void_p
 from ctypes import byref, cast, create_string_buffer, POINTER, sizeof
 import platform
 import threading
 
+import tellcore.constants as const
+
 
 if platform.system() == 'Windows':
     from ctypes import WINFUNCTYPE as FUNCTYPE, windll as DllLoader
     LIBRARY_NAME = 'TelldusCore.dll'
 else:
     from ctypes import CFUNCTYPE as FUNCTYPE, cdll as DllLoader
-    LIBRARY_NAME = 'libtelldus-core.so.2'
+    if platform.system() == 'Darwin':
+        LIBRARY_NAME = '/Library/Frameworks/TelldusCore.framework/TelldusCore'
+    else:
+        LIBRARY_NAME = 'libtelldus-core.so.2'
 
 DEVICE_EVENT_FUNC = FUNCTYPE(
     None, c_int, c_int, c_char_p, c_int, c_void_p)
@@ -74,7 +79,7 @@ class BaseCallbackDispatcher(object):
         :param callable callback: The callback function to call.
         :param args: The arguments to pass to the callback.
         """
-        pass
+        raise NotImplementedError
 
 
 class DirectCallbackDispatcher(BaseCallbackDispatcher):
@@ -124,7 +129,7 @@ class Library(object):
                 if type(param) is unicode:
                     return cls(param)
             except NameError:
-                pass # The unicode type does not exist in python 3
+                pass  # The unicode type does not exist in python 3
             return c_char_p.from_param(param)
 
     # Must be a separate class (i.e. not part of Library), to avoid circular
@@ -254,11 +259,16 @@ class Library(object):
         return char_p.value.decode(Library.STRING_ENCODING)
 
     def _setup_functions(self, lib):
-        def check_result(result, func, args):
+        def check_int_result(result, func, args):
             if result < 0:
                 raise TelldusError(result)
             return result
 
+        def check_bool_result(result, func, args):
+            if not result:
+                raise TelldusError(const.TELLSTICK_ERROR_DEVICE_NOT_FOUND)
+            return result
+
         def free_string(result, func, args):
             string = cast(result, c_char_p).value
             if string is not None:
@@ -273,7 +283,9 @@ class Library(object):
                 func.argtypes = signature[1]
 
                 if func.restype == c_int:
-                    func.errcheck = check_result
+                    func.errcheck = check_int_result
+                elif func.restype == c_bool:
+                    func.errcheck = check_bool_result
                 elif func.restype == c_char_p:
                     func.restype = c_void_p
                     func.errcheck = free_string
