@@ -21,8 +21,8 @@ except ImportError:
     # Fall back on old (python 2) variant
     import Queue as queue
 
-from .constants import *
-from .library import Library, TelldusError, BaseCallbackDispatcher
+import tellcore.constants as const
+from tellcore.library import Library, TelldusError, BaseCallbackDispatcher
 
 
 class QueuedCallbackDispatcher(BaseCallbackDispatcher):
@@ -103,8 +103,8 @@ class TelldusCore(object):
         devices = []
         count = self.lib.tdGetNumberOfDevices()
         for i in range(count):
-            id = self.lib.tdGetDeviceId(i)
-            devices.append(Device(id, lib=self.lib))
+            device = Device(self.lib.tdGetDeviceId(i), lib=self.lib)
+            devices.append(device)
         return devices
 
     def sensors(self):
@@ -118,7 +118,7 @@ class TelldusCore(object):
                 sensor = self.lib.tdSensor()
                 sensors.append(Sensor(lib=self.lib, **sensor))
         except TelldusError as e:
-            if e.error != TELLSTICK_ERROR_DEVICE_NOT_FOUND:
+            if e.error != const.TELLSTICK_ERROR_DEVICE_NOT_FOUND:
                 raise
         return sensors
 
@@ -133,15 +133,17 @@ class TelldusCore(object):
         try:
             while True:
                 controller = self.lib.tdController()
+                del controller["name"]
+                del controller["available"]
                 controllers.append(Controller(lib=self.lib, **controller))
         except TelldusError as e:
-            if e.error != TELLSTICK_ERROR_NOT_FOUND:
+            if e.error != const.TELLSTICK_ERROR_NOT_FOUND:
                 raise
         return controllers
 
     def add_device(self, name, protocol, model=None, **parameters):
         """Add a new device to Telldus Core."""
-        device = Device(self.lib.tdAddDevice())
+        device = Device(self.lib.tdAddDevice(), lib=self.lib)
         try:
             device.name = name
             device.protocol = protocol
@@ -150,12 +152,18 @@ class TelldusCore(object):
             for key, value in parameters.items():
                 device.set_parameter(key, value)
             return device
-        except Exception as e:
+        except Exception:
+            import sys
+            exc_info = sys.exc_info()
             try:
                 device.remove()
             except:
                 pass
-            raise e
+
+            if "with_traceback" in dir(Exception):
+                raise exc_info[0].with_traceback(exc_info[1], exc_info[2])
+            else:
+                exec("raise exc_info[0], exc_info[1], exc_info[2]")
 
     def send_raw_command(self, command, reserved=0):
         return self.lib.tdSendRawCommand(command, reserved)
@@ -178,9 +186,9 @@ class Device(object):
                   "fade"]
 
     def __init__(self, id, lib=None):
-        lib = Library() if lib is None else lib
-
         super(Device, self).__init__()
+
+        lib = Library() if lib is None else lib
         super(Device, self).__setattr__('id', id)
         super(Device, self).__setattr__('lib', lib)
 
@@ -210,7 +218,7 @@ class Device(object):
             func = self.lib.tdSetModel
         else:
             raise AttributeError(name)
-        return func(self.id, value)
+        func(self.id, value)
 
     def parameters(self):
         parameters = {}
@@ -229,7 +237,7 @@ class Device(object):
         return value
 
     def set_parameter(self, name, value):
-        return self.lib.tdSetDeviceParameter(self.id, name, str(value))
+        self.lib.tdSetDeviceParameter(self.id, name, str(value))
 
     def turn_on(self):
         """Turn on the device."""
@@ -280,6 +288,14 @@ class Device(object):
 
 
 class Sensor(object):
+    DATATYPES = {"temperature": const.TELLSTICK_TEMPERATURE,
+                 "humidity": const.TELLSTICK_HUMIDITY,
+                 "rainrate": const.TELLSTICK_RAINRATE,
+                 "raintotal": const.TELLSTICK_RAINTOTAL,
+                 "winddirection": const.TELLSTICK_WINDDIRECTION,
+                 "windaverage": const.TELLSTICK_WINDAVERAGE,
+                 "windgust": const.TELLSTICK_WINDGUST}
+
     def __init__(self, protocol, model, id, datatypes, lib=None):
         super(Sensor, self).__init__()
         self.protocol = protocol
@@ -288,49 +304,49 @@ class Sensor(object):
         self.datatypes = datatypes
         self.lib = Library() if lib is None else lib
 
+    def has_value(self, datatype):
+        return (self.datatypes & datatype) != 0
+
     def value(self, datatype):
         value = self.lib.tdSensorValue(
             self.protocol, self.model, self.id, datatype)
-        return SensorValue(value['value'], value['timestamp'])
+        return SensorValue(datatype, value['value'], value['timestamp'])
 
-    def has_temperature(self):
-        return self.datatypes & TELLSTICK_TEMPERATURE != 0
-
-    def has_humidity(self):
-        return self.datatypes & TELLSTICK_HUMIDITY != 0
-
-    def temperature(self):
-        return self.value(TELLSTICK_TEMPERATURE)
-
-    def humidity(self):
-        return self.value(TELLSTICK_HUMIDITY)
+    def __getattr__(self, name):
+        typename = name.replace("has_", "", 1)
+        if typename in Sensor.DATATYPES:
+            datatype = Sensor.DATATYPES[typename]
+            if name == typename:
+                return lambda: self.value(datatype)
+            else:
+                return lambda: self.has_value(datatype)
+        raise AttributeError(name)
 
 
 class SensorValue(object):
-    __slots__ = ["value", "timestamp"]
+    __slots__ = ["datatype", "value", "timestamp"]
 
-    def __init__(self, value, timestamp):
+    def __init__(self, datatype, value, timestamp):
         super(SensorValue, self).__init__()
+        self.datatype = datatype
         self.value = value
         self.timestamp = timestamp
 
 
 class Controller(object):
-    def __init__(self, id, type, name, available, lib=None):
+    def __init__(self, id, type, lib=None):
         lib = Library() if lib is None else lib
 
         super(Controller, self).__init__()
         super(Controller, self).__setattr__('id', id)
         super(Controller, self).__setattr__('type', type)
-        super(Controller, self).__setattr__('name', name)
-        super(Controller, self).__setattr__('available', available)
         super(Controller, self).__setattr__('lib', lib)
 
     def __getattr__(self, name):
         try:
             return self.lib.tdControllerValue(self.id, name)
         except TelldusError as e:
-            if e.error == TELLSTICK_ERROR_METHOD_NOT_SUPPORTED:
+            if e.error == const.TELLSTICK_ERROR_METHOD_NOT_SUPPORTED:
                 raise AttributeError(name)
             raise
 
@@ -338,6 +354,6 @@ class Controller(object):
         try:
             self.lib.tdSetControllerValue(self.id, name, value)
         except TelldusError as e:
-            if e.error == TELLSTICK_ERROR_SYNTAX:
+            if e.error == const.TELLSTICK_ERROR_SYNTAX:
                 raise AttributeError(name)
             raise
